Skip to main content

ezflix

Command line utility that allows you to search for TV and movie torrents and stream using Peerflix automatically.

Install

ezflix is available on the Python Package Index (PyPI) at https://pypi.python.org/pypi/ezflix

You can ezflix using pip.

pip install ezflix

This program requires Peerflix. You can install Peerflix via NPM.

npm install -g peerflix

Supported Media Players

Below is a list of media players supported in Peerflix.

  • mpv

  • airplay

  • vlc

  • mplayer

  • smplayer

  • mpchc

  • potplayer

  • webplay

  • omx

In ezflix, the default player is mpv. It will fallback to vlc if mpv isn’t found.

You can use the media_player flag to set your media player.

Usage

usage: __main__.py [-h] [--limit [LIMIT]] [--media_player [MEDIA_PLAYER]]
                   [--latest] [--subtitles]
                   [--sort_by [{download_count,like_count,date_added,seeds,peers,rating,title,year}]]
                   [--sort_order [{asc,desc}]] [--quality [{720p,1080p,3d}]]
                   [{movie,tv}] query

positional arguments:
  {movie,tv}            The media type.
  query                 The search query.

optional arguments:
  -h, --help            show this help message and exit
  --limit [LIMIT]       The number of results to return.
  --media_player [MEDIA_PLAYER]
                        The media player.
  --latest              Play the latest TV episode.
  --subtitles           Load subtitles file.
  --sort_by [{download_count,like_count,date_added,seeds,peers,rating,title,year}]
                        Use this argument to sort the torrents.
  --sort_order [{asc,desc}]
                        Use this argument to set the sort order.
  --quality [{720p,1080p,3d}]
                        Use this argument to set the min quality.

Examples

ezflix "The Man in the High Castle"

Pass ‘–latest’ to watch the latest episode of a given TV series.

ezflix "South Park" --latest

To search for movies, pass the ‘movie’ argument.

ezflix movie "Mad Max"

Search for movies released in 2017 and order by like count descending.

ezflix movie '2017' --sort_by=like_count --sort_order=desc

Run development version

Before any new changes are pushed to PyPi, you can clone the development version to avail of any new features.

git clone https://github.com/AnthonyBloomer/ezflix.git && cd ezflix
virtualenv env
source env/bin/activate
pip install -r requirements.txt
python setup.py install

Contributing

  • Fork the project and clone locally.

  • Create a new branch for what you’re going to work on.

  • Push to your origin repository.

  • Create a new pull request in GitHub.

Metadata

Release files for ezflix 1.0.3

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for ezflix 1.0.3
File Size Uploaded
ezflix-1.0.3.tar.gz 5.5 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for ezflix 1.0.3
File Interpreter ABI Platform
ezflix-1.0.3-py2-none-any.whl Python 2 none any Details

Total release size: 14.8 kB

Release files / ezflix-1.0.3.tar.gz

Download URL ezflix-1.0.3.tar.gz
Size 5.5 kB
Tags Source
SHA-256 checksum
How to use checksums
4bf5018ad5aff55955dd2894e7c991358913555bc5e9c970280df2f5549a4b58
BLAKE2b-256 checksum
How to use checksums
a096f73990263e858716182ce0cd2c717f7b80a8aafe7097d8fa3d5e978e82b4
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / ezflix-1.0.3-py2-none-any.whl

Download URL ezflix-1.0.3-py2-none-any.whl
Size 9.3 kB
Tags Python 2
SHA-256 checksum
How to use checksums
3d93b8cd7f02ab96e6a7aeec7238717e70979ae6db41683ea113b378d3a1c980
BLAKE2b-256 checksum
How to use checksums
888269a4ea1e7d8ecb12ded0e86f95b789906876964c035418ad79db75756431
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release history Release notifications | RSS feed

1.6.5

2 release files

1.6.4

2 release files

1.6.3

2 release files

1.6.2

2 release files

1.6.1

2 release files

1.6.0

2 release files

1.5.6

2 release files

1.5.5

2 release files

1.5.4

2 release files

1.5.3

2 release files

1.5.2

2 release files

1.5.1

2 release files

1.5.0

2 release files

1.4.9

2 release files

1.4.8

2 release files

1.4.7

2 release files

1.4.6

2 release files

1.4.5

2 release files

1.4.4

2 release files

1.4.3

2 release files

1.4.2

2 release files

1.4.1

2 release files

1.4.0

2 release files

1.3.0

2 release files

1.2.0

2 release files

1.1.0

2 release files

1.0.9

2 release files

1.0.8

2 release files

1.0.7

2 release files

1.0.6

2 release files

1.0.5

2 release files

1.0.4

2 release files

This release

1.0.3 This release

2 release files

1.0.2

2 release files

1.0.1

2 release files

1.0.0

2 release files

0.0.9

2 release files

0.0.8

2 release files

0.0.7

2 release files

0.0.5

2 release files

0.0.4

2 release files

0.0.3

2 release files

0.0.2

2 release files

0.0.1

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page